@@ -45,9 +45,7 @@ class TestDatabase:
             now = datetime(2023, 10, 20, 22, 35, 55, tzinfo=timezone.utc)
             rows = [{"test_date": now}]
             dbdatabase.batch_populate(rows, DBTestDate)
-            dbtestdate = (
-                dbsession.execute(select(DBTestDate)).all()[1][0].test_date
-            )
+            dbtestdate = dbsession.execute(select(DBTestDate)).all()[1][0].test_date
             assert dbtestdate == now
 
         remove(dbpath)
